@@ -465,11 +465,10 @@ macro_rules! put {
 }
 
 macro_rules! get_interface {
-    ($get_method:ident, $T: ident, $VT: ident) => {
+    ($get_method:ident, $T: ident) => {
         pub fn $get_method(&self) -> Result<$T> {
-            let mut ppv = MaybeUninit::<*mut *mut $VT>::uninit();
-            check_hresult(unsafe { self.inner.$get_method(ppv.as_mut_ptr()) })?;
-            let ppv = unsafe { ppv.assume_init() };
+            let mut ppv = ptr::null_mut();
+            check_hresult(unsafe { self.inner.$get_method(&mut ppv) })?;
             if ppv.is_null() {
                 Err(Error::new(E_FAIL))
             } else {
@@ -1175,11 +1174,7 @@ impl HttpRequestHeaders {
         check_hresult(unsafe { self.inner.set_header(name.as_ptr(), value.as_ptr()) })
     }
     put_string!(remove_header);
-    get_interface!(
-        get_iterator,
-        HttpHeadersCollectionIterator,
-        ICoreWebView2HttpHeadersCollectionIteratorVTable
-    );
+    get_interface!(get_iterator, HttpHeadersCollectionIterator);
 }
 
 impl HttpResponseHeaders {
@@ -1218,11 +1213,7 @@ impl HttpResponseHeaders {
             inner: unsafe { add_ref_to_rc(iterator) },
         })
     }
-    get_interface!(
-        get_iterator,
-        HttpHeadersCollectionIterator,
-        ICoreWebView2HttpHeadersCollectionIteratorVTable
-    );
+    get_interface!(get_iterator, HttpHeadersCollectionIterator);
 }
 
 impl Deferral {
@@ -1234,23 +1225,15 @@ impl WebResourceRequest {
     put_string!(put_uri);
     get_string!(get_method);
     put_string!(put_method);
-    get_interface!(get_content, Stream, IStreamVTable);
+    get_interface!(get_content, Stream);
     put_interface!(put_content, Stream);
-    get_interface!(
-        get_headers,
-        HttpRequestHeaders,
-        ICoreWebView2HttpRequestHeadersVTable
-    );
+    get_interface!(get_headers, HttpRequestHeaders);
 }
 
 impl WebResourceResponse {
-    get_interface!(get_content, Stream, IStreamVTable);
+    get_interface!(get_content, Stream);
     put_interface!(put_content, Stream);
-    get_interface!(
-        get_headers,
-        HttpResponseHeaders,
-        ICoreWebView2HttpResponseHeadersVTable
-    );
+    get_interface!(get_headers, HttpResponseHeaders);
     get!(get_status_code, i32);
     put!(put_status_code, status_code: i32);
     get_string!(get_reason_phrase);
@@ -1258,18 +1241,10 @@ impl WebResourceResponse {
 }
 
 impl WebResourceRequestedEventArgs {
-    get_interface!(
-        get_request,
-        WebResourceRequest,
-        ICoreWebView2WebResourceRequestVTable
-    );
-    get_interface!(
-        get_response,
-        WebResourceResponse,
-        ICoreWebView2WebResourceResponseVTable
-    );
+    get_interface!(get_request, WebResourceRequest);
+    get_interface!(get_response, WebResourceResponse);
     put_interface!(put_response, WebResourceResponse);
-    get_interface!(get_deferral, Deferral, ICoreWebView2DeferralVTable);
+    get_interface!(get_deferral, Deferral);
     get!(get_resource_context, WebResourceContext);
 }
 
@@ -1283,11 +1258,7 @@ impl NavigationStartingEventArgs {
     get_string!(get_uri);
     get_bool!(get_is_user_initiated);
     get_bool!(get_is_redirected);
-    get_interface!(
-        get_request_headers,
-        HttpRequestHeaders,
-        ICoreWebView2HttpRequestHeadersVTable
-    );
+    get_interface!(get_request_headers, HttpRequestHeaders);
     get_bool!(get_cancel);
     put_bool!(put_cancel);
     get!(get_navigation_id, u64);
@@ -1305,7 +1276,7 @@ impl ScriptDialogOpeningEventArgs {
     get_string!(get_default_text);
     get_string!(get_result_text);
     put_string!(put_result_text);
-    get_interface!(get_deferral, Deferral, ICoreWebView2DeferralVTable);
+    get_interface!(get_deferral, Deferral);
 }
 
 impl PermissionRequestedEventArgs {
@@ -1314,7 +1285,7 @@ impl PermissionRequestedEventArgs {
     get_bool!(get_is_user_initiated);
     get!(get_state, PermissionState);
     put!(put_state, state: PermissionState);
-    get_interface!(get_deferral, Deferral, ICoreWebView2DeferralVTable);
+    get_interface!(get_deferral, Deferral);
 }
 
 impl ProcessFailedEventArgs {
@@ -1324,16 +1295,12 @@ impl ProcessFailedEventArgs {
 impl NewWindowRequestedEventArgs {
     get_string!(get_uri);
     put_interface!(put_new_window, WebView);
-    get_interface!(get_new_window, WebView, ICoreWebView2VTable);
+    get_interface!(get_new_window, WebView);
     put_bool!(put_handled);
     get_bool!(get_handled);
     get_bool!(get_is_user_initiated);
-    get_interface!(get_deferral, Deferral, ICoreWebView2DeferralVTable);
-    get_interface!(
-        get_window_features,
-        WindowFeatures,
-        ICoreWebView2WindowFeaturesVTable
-    );
+    get_interface!(get_deferral, Deferral);
+    get_interface!(get_window_features, WindowFeatures);
 }
 
 impl WindowFeatures {
